@@ -1,6 +1,6 @@
 package Net::Joker::DMAPI;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 use strict;
 use warnings;
 use 5.010;
@@ -276,6 +276,11 @@ sub do_request {
     );
     my $response = $self->ua->get($url);
 
+    $self->_log(
+        info => "$method response status " . $response->status_line
+            . " - body: $response->decoded_content"
+    );
+
     if (!$response->is_success) {
         my $error = "$method request failed: " . $response->status_line;
         $self->_log( error => $error );
@@ -306,10 +311,6 @@ sub do_request {
 
         $self->balance($headers{'Account-Balance'}) if defined $headers{'Account-Balance'};
         $self->auth_sid($headers{'Auth-Sid'}) if $headers{'Auth-Sid'};
-        $self->_log(
-            info => "$method response status " . $response->status_line
-                . " - body: $content"
-        );
 
         return wantarray ? ($body, %headers) : $body;
     };
@@ -498,6 +499,11 @@ sub DESTROY {
 
 David Precious C<< <davidp@preshweb.co.uk> >>
 
+=head1 ACKNOWLEDGEMENTS
+
+Tomasz Czepiel (@tczepiel)
+
+
 =head1 BUGS / FEATURE REQUESTS
 
 If you've found a bug, or have a feature request or wish to contribute a patch,
@@ -528,5 +534,5 @@ or parsing of responses, just the basics.
 =cut
 
 
-"Joker, your API smells of wee.";
+1;
 
